==> scummvm_2.2.0+dfsg1.orig.tar.xz: scummvm-2.2.0/engines/ultima/ultima1/actions/ready.cpp <==
/* ScummVM - Graphic Adventure Engine
 *
 * ScummVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the COPYRIGHT
 * file distributed with this source distribution.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 */

#include "ultima/ultima1/actions/ready.h"
#include "ultima/ultima1/u1dialogs/ready.h"
#include "ultima/ultima1/core/resources.h"
#include "ultima/ultima1/game.h"

namespace Ultima {
namespace Ultima1 {
namespace Actions {

BEGIN_MESSAGE_MAP(Ready, Action)
	ON_MESSAGE(ReadyMsg)
END_MESSAGE_MAP()

bool Ready::ReadyMsg(CReadyMsg &msg) {
	Ultima1Game *game = static_cast<Ultima1Game *>(getGame());
	addInfoMsg(game->_res->ACTION_NAMES[17], false);

	U1Dialogs::Ready *dialog = new U1Dialogs::Ready(game);
	dialog->show();

	return true;
}

} // End of namespace Actions
} // End of namespace Ultima1
} // End of namespace Ultima

==> scummvm_2.5.1+dfsg.orig.tar.xz: scummvm-2.5.1/engines/ultima/ultima1/actions/ready.cpp <==
/* ScummVM - Graphic Adventure Engine
 *
 * ScummVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the COPYRIGHT
 * file distributed with this source distribution.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 */

#include "ultima/ultima1/actions/ready.h"
#include "ultima/ultima1/u1dialogs/ready.h"
#include "ultima/ultima1/core/resources.h"
#include "ultima/ultima1/game.h"

namespace Ultima {
namespace Ultima1 {
namespace Actions {

BEGIN_MESSAGE_MAP(Ready, Action)
	ON_MESSAGE(ReadyMsg)
END_MESSAGE_MAP()

bool Ready::ReadyMsg(CReadyMsg *msg) {
	Ultima1Game *game = static_cast<Ultima1Game *>(getGame());
	addInfoMsg(game->_res->ACTION_NAMES[17], false);

	U1Dialogs::Ready *dialog = new U1Dialogs::Ready(game);
	dialog->show();

	return true;
}

} // End of namespace Actions
} // End of namespace Ultima1
} // End of namespace Ultima
